@@ -14,7 +14,20 @@ import (
 )
 
 func renderMachineStatus(ctx context.Context, app *api.AppCompact) (err error) {
-	io := iostreams.FromContext(ctx)
+	var (
+		io     = iostreams.FromContext(ctx)
+		client = client.FromContext(ctx).API()
+	)
+
+	agentclient, err := agent.Establish(ctx, client)
+	if err != nil {
+		return fmt.Errorf("unable to establish agent: %s", err)
+	}
+
+	dialer, err := agentclient.Dialer(ctx, app.Organization.Slug)
+	if err != nil {
+		return fmt.Errorf("ssh: can't build tunnel for %s: %s", app.Organization.Slug, err)
+	}
 
 	flapsClient, err := flaps.New(ctx, app)
 	if err != nil {
@@ -26,6 +39,22 @@ func renderMachineStatus(ctx context.Context, app *api.AppCompact) (err error) {
 		return err
 	}
 
+	if app.IsPostgresApp() {
+		var roles = map[string]*api.Machine{}
+
+		for _, machine := range machines {
+			pgCli := flypg.NewFromInstance(fmt.Sprintf("[%s]", machine.PrivateIP), dialer)
+
+			role, err := pgCli.NodeRole(ctx)
+			if err != nil {
+				// TODO - Determine best way to present this error.
+				role = "error"
+			}
+			roles[role] = machine
+		}
+		return renderPGStatus(ctx, app, roles)
+	}
+
 	obj := [][]string{
 		{
 			app.Name,
@@ -39,10 +68,6 @@ func renderMachineStatus(ctx context.Context, app *api.AppCompact) (err error) {
 		return
 	}
 
-	if app.IsPostgresApp() {
-		return renderPGStatus(ctx, app, machines)
-	}
-
 	rows := [][]string{}
 
 	for _, machine := range machines {
@@ -50,54 +75,36 @@ func renderMachineStatus(ctx context.Context, app *api.AppCompact) (err error) {
 			machine.ID,
 			machine.State,
 			machine.Region,
+			render.MachineHealthChecksSummary(machine),
 			machine.ImageRefWithVersion(),
 			machine.CreatedAt,
 			machine.UpdatedAt,
 		})
 	}
 
-	_ = render.Table(io.Out, "", rows, "ID", "State", "Region", "Image", "Created", "Updated")
+	_ = render.Table(io.Out, "", rows, "ID", "State", "Region", "Health checks", "Image", "Created", "Updated")
 
 	return
 }
 
-func renderPGStatus(ctx context.Context, app *api.AppCompact, machines []*api.Machine) (err error) {
-	io := iostreams.FromContext(ctx)
-	client := client.FromContext(ctx).API()
-
-	agentclient, err := agent.Establish(ctx, client)
-	if err != nil {
-		return fmt.Errorf("unable to establish agent: %s", err)
-	}
-
-	dialer, err := agentclient.Dialer(ctx, app.Organization.Slug)
-	if err != nil {
-		return fmt.Errorf("ssh: can't build tunnel for %s: %s", app.Organization.Slug, err)
-	}
+func renderPGStatus(ctx context.Context, app *api.AppCompact, machines map[string]*api.Machine) (err error) {
+	var io = iostreams.FromContext(ctx)
 
 	rows := [][]string{}
 
-	for _, machine := range machines {
-		pgCli := flypg.NewFromInstance(fmt.Sprintf("[%s]", machine.PrivateIP), dialer)
-
-		role, err := pgCli.NodeRole(ctx)
-		if err != nil {
-			// TODO - Determine best way to present this error.
-			role = "error"
-		}
-
+	for role, machine := range machines {
 		rows = append(rows, []string{
 			machine.ID,
 			machine.State,
 			role,
 			machine.Region,
+			render.MachineHealthChecksSummary(machine),
 			machine.ImageRefWithVersion(),
 			machine.CreatedAt,
 			machine.UpdatedAt,
 		})
 	}
-
-	_ = render.Table(io.Out, "", rows, "ID", "State", "Role", "Region", "Image", "Created", "Updated")
+	_ = render.Table(io.Out, "", rows, "ID", "State", "Role", "Region", "Health checks", "Image", "Created", "Updated")
 
 	return
 }
